@@ -614,10 +614,6 @@ detect_gpm (void)
   fd = open ("/dev/gpmdata", O_RDONLY | O_NONBLOCK);
   if (fd < 0)
     return 0;
-  if (bogl_cloexec (fd) < 0) {
-    close (fd);
-    return 0;
-  }
   
   /* Poll the mouse whether or not we could find gpm, in
      case it starts up later; but keep searching in that case. */
@@ -644,10 +640,6 @@ detect_input (void)
   fd = open("/dev/input/mice", O_RDONLY | O_NONBLOCK);
   if(fd < 0)
     return;
-  if (bogl_cloexec(fd) < 0) {
-    close(fd);
-    return;
-  }
 
   add_mouse(T_PS2, fd);
 }
@@ -667,10 +659,6 @@ detect_ps2 (void)
   fd = open ("/dev/psaux", O_RDWR | O_NONBLOCK);
   if (fd < 0)
     return;
-  if (bogl_cloexec (fd) < 0) {
-    close (fd);
-    return;
-  }
 
   write (fd, s2, sizeof s2);
   usleep (30000);
@@ -707,10 +695,6 @@ detect_msbus (void)
   int fd = open ("/dev/inportbm", O_RDONLY | O_NONBLOCK);
   if (fd < 0)
     return;
-  if (bogl_cloexec (fd) < 0) {
-    close (fd);
-    return;
-  }
 
   add_mouse (T_MS_BUS, fd);
 }
@@ -723,10 +707,6 @@ detect_adb (void)
   int fd = open ("/dev/adbmouse", O_RDONLY | O_NONBLOCK);
   if (fd < 0)
     return;
-  if (bogl_cloexec (fd) < 0) {
-    close (fd);
-    return;
-  }
 
   add_mouse (T_ADB, fd);
 }
@@ -741,10 +721,6 @@ detect_sun (void)
   int fd = open ("/dev/sunmouse", O_RDONLY | O_NONBLOCK);
   if (fd < 0)
     return;
-  if (bogl_cloexec (fd) < 0) {
-    close (fd);
-    return;
-  }
 
   add_mouse (T_SUN, fd);
 }
@@ -1002,11 +978,6 @@ open_serial_port (char *port)
   fd = open (port, O_RDWR | O_NONBLOCK);
   if (fd < 0)
     return fd;
-  if (bogl_cloexec (fd) < 0)
-    {
-      close (fd);
-      return -1;
-    }
 
   /* Reset file so it is no longer in non-blocking mode. */
   if (fcntl (fd, F_SETFL, 0) < 0)
